#!/usr/bin/perl -w

#------------------------------------------------------------------------------
#                  GEOS-Chem Global Chemical Transport Model                  !
#------------------------------------------------------------------------------
#BOP
#
# !IROUTINE: job_depend.pl
#
# !DESCRIPTION: Submits several jobs to the SLURM scheduler, such that
#  each job will wait for the previous job to be done.  Handy for
#  submitting stages of long model runs.
#\\
#\\
# !REMARKS:
#  Add the job script names to the @jobs array.
#
# !REVISION HISTORY:
#  16 Mar 2018 - R. Yantosca - Initial version
#EOP
#------------------------------------------------------------------------------
#BOC
#
# !LOCAL VARIABLES:
#

# Scalars
my $count   = 0;

# Strings
my $depend = "";
my $result = "";
my $job    = "";
my $jobId  = "";

# Arrays
my @subStr = ();
my @jobs   = qw/v11-02f-Run1.20150101.spinup
                v11-02f-Run1.20150201.spinup
                v11-02f-Run1.20150301.spinup
                v11-02f-Run1.20150401.spinup
                v11-02f-Run1.20150501.spinup
                v11-02f-Run1.20150601.spinup
                v11-02f-Run1.20150701.spinup
                v11-02f-Run1.20150801.spinup
                v11-02f-Run1.20150901.spinup
                v11-02f-Run1.20151001.spinup
                v11-02f-Run1.20151101.spinup
                v11-02f-Run1.20151201.spinup
                v11-02f-Run1.20160101
                v11-02f-Run1.20160201
                v11-02f-Run1.20160301
                v11-02f-Run1.20160401
                v11-02f-Run1.20160501
                v11-02f-Run1.20160601
                v11-02f-Run1.20160701
                v11-02f-Run1.20160801
                v11-02f-Run1.20160901
                v11-02f-Run1.20161001
                v11-02f-Run1.20161101
                v11-02f-Run1.20161201/;

# Loop over jobs
foreach $job ( @jobs ) {

  # Add the dependency string after the first job is submitted
  # (On the first pass, it's a blank string)
  if ( $count > 0 ) { $depend = "--dependency=afterok:$jobId "; }

  # Submit the job
  $cmd    = "sbatch $depend $job";
  print "$cmd\n";
  $result = qx/$cmd/;
  print "$result";

  # The job ID Is the last substring 
  @subStr = split( ' ', $result );
  $jobId  = $subStr[3];
  
  # Increment count
  $count++;
}

exit( $? );
